@@ -231,7 +231,15 @@ EntityTypeDef = TypedDict(
 ICD10CMAttributeTypeDef = TypedDict(
     "ICD10CMAttributeTypeDef",
     {
-        "Type": Literal["ACUITY", "DIRECTION", "SYSTEM_ORGAN_SITE", "QUALITY", "QUANTITY"],
+        "Type": Literal[
+            "ACUITY",
+            "DIRECTION",
+            "SYSTEM_ORGAN_SITE",
+            "QUALITY",
+            "QUANTITY",
+            "TIME_TO_DX_NAME",
+            "TIME_EXPRESSION",
+        ],
         "Score": float,
         "RelationshipScore": float,
         "Id": int,
@@ -239,6 +247,8 @@ ICD10CMAttributeTypeDef = TypedDict(
         "EndOffset": int,
         "Text": str,
         "Traits": List["ICD10CMTraitTypeDef"],
+        "Category": Literal["DX_NAME", "TIME_EXPRESSION"],
+        "RelationshipType": Literal["OVERLAP", "SYSTEM_ORGAN_SITE"],
     },
     total=False,
 )
@@ -253,7 +263,7 @@ ICD10CMEntityTypeDef = TypedDict(
         "Id": int,
         "Text": str,
         "Category": Literal["MEDICAL_CONDITION"],
-        "Type": Literal["DX_NAME"],
+        "Type": Literal["DX_NAME", "TIME_EXPRESSION"],
         "Score": float,
         "BeginOffset": int,
         "EndOffset": int,
